--
-- Selected TOC Entries:
--
--
-- TOC Entry ID 2 (OID 1960642)
--
-- Name: field Type: TABLE Owner: aliphe
--

CREATE TABLE field (
	object_id integer NOT NULL,
	externalname character varying(50) NOT NULL,
	datatypeid character varying(20) DEFAULT 'varchar' NOT NULL,
	datalength smallint NOT NULL,
	datascale smallint,
	dataformat character varying(50),
	fieldorder smallint NOT NULL,
	fieldpos smallint,
	keyposition smallint,
	localfield character varying(3) DEFAULT 'no' NOT NULL,
	referto_id integer,
	xmlnode character varying(50),
	defaultvalue character varying(250),
	nullable character varying(10) DEFAULT 'yes',
	Constraint field_pkey Primary Key (object_id)
);

